Documentation
¶
Overview ¶
The identity package has methods and structures relating to methods of identification on the AirDispatch network including Signing Keys, Encryption Keys, Address Fingerprints, and more!
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Address ¶
type Address struct {
// The fingerprint of the address signingKey
Fingerprint []byte
// The location of the user's server
Location string
// The publicKey of the user
EncryptionKey *rsa.PublicKey
// The signingKey of the user
SigningKey *ecdsa.PublicKey
// Optional Alias of the Address
Alias string
// contains filtered or unexported fields
}
The address structure provides abstractions on AirDispatch addresses
The Public variable has an address that can represent sending a message to the public.
func (*Address) IsPublic ¶
Compares the Address to the `Public Address`.
type Identity ¶
type Identity struct {
Address *Address
EncryptionKey *rsa.PrivateKey
SigningKey *ecdsa.PrivateKey
}
The Identity structure is a complete AirDispatch user including Encryption and Signing private keys.
WARNING: This structure should be stored carefully as having access to this data will be enough to impersonate someone on the AirDispatch network.
func CreateIdentity ¶
This creates a new random, AirDispatch Identity
func GobDecodeKey ¶
This function loads a Gob-Encoded ADKey from a buffer
func LoadKeyFromFile ¶
This function Loads an Airdispatch Key from a File
func (*Identity) GobEncodeKey ¶
This function writes a Gob-Encoded ADKey to a buffer
func (*Identity) SaveKeyToFile ¶
This function Saves an Airdispatch Key to a File
Source Files
¶
- address.go
- fs.go
- identity.go